@@ -30,6 +30,7 @@ MobileShellSettings::MobileShellSettings(QObject *parent)
             Q_EMIT vibrationsEnabledChanged();
             Q_EMIT vibrationDurationChanged();
             Q_EMIT animationsEnabledChanged();
+            Q_EMIT dateInStatusBarChanged();
             Q_EMIT navigationPanelEnabledChanged();
             Q_EMIT alwaysShowKeyboardToggleOnNavigationPanelChanged();
             Q_EMIT keyboardButtonEnabledChanged();
@@ -80,6 +81,19 @@ void MobileShellSettings::setAnimationsEnabled(bool animationsEnabled)
     m_config->sync();
 }
 
+bool MobileShellSettings::dateInStatusBar() const
+{
+    auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
+    return group.readEntry("dateInStatusBar", false);
+}
+
+void MobileShellSettings::setDateInStatusBar(bool dateInStatusBar)
+{
+    auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
+    group.writeEntry("dateInStatusBar", dateInStatusBar, KConfigGroup::Notify);
+    m_config->sync();
+}
+
 bool MobileShellSettings::navigationPanelEnabled() const
 {
     auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
@@ -168,9 +182,7 @@ void MobileShellSettings::updateNavigationBarsInPlasma(bool navigationPanelEnabl
 
     if (navigationPanelEnabled) {
         QString createNavigationPanelScript = R"(
-            var bottomPanel = new Panel("org.kde.plasma.mobile.taskpanel")
-            bottomPanel.location = "bottom";
-            bottomPanel.height = 2 * gridUnit;
+            loadTemplate("org.kde.plasma.mobile.defaultNavigationPanel");
         )";
 
         message << createNavigationPanelScript;
